# We ship a .pc file but don't want to have a dep on pkg-config. We
# strip the automatically generated dep here and instead co-own the
# directory.
%global __requires_exclude pkg-config

%global gitversion 28cb22e
%global gitdate 20130626
%global libmajor 8
%global libversion %{libmajor}.0.2

Name:           pacman
Version:        4.1.2
Release:        1.%{gitdate}git%{gitversion}%{?dist}
Source:         https://projects.archlinux.org/%{name}.git/snapshot/%{name}-%{gitversion}.tar.gz
Url:            https://www.archlinux.org/pacman
License:        GPLv2+
Summary:        Package manager for the Arch distribution
# mirrorlist retrieved from https://www.archlinux.org/mirrorlist/all
# with mirrors.kernel.org uncommented
Source1:        mirrorlist

BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  gettext-devel
BuildRequires:  asciidoc
BuildRequires:  doxygen
BuildRequires:  libarchive-devel
BuildRequires:  gpgme-devel
BuildRequires:  openssl-devel
BuildRequires:  libcurl-devel
Requires:       %{name}-filesystem = %{version}-%{release}

%description
Pacman is the package manager used by the Arch distribution. It is a
frontend for the ALPM (Arch Linux Package Management) library.

Pacman does not strive to "do everything." It will add, remove and
upgrade packages in the system, and it will allow you to query the
package database for installed packages, files and owners. It also
attempts to handle dependencies automatically and can download
packages from a remote server. Arch packages are simple archives, with
.pkg.tar.gz extension for binary packages and .src.tar.gz for source
packages.


%package -n libalpm
Summary: Arch Linux Package Management library

%description -n libalpm

This library is the backend behind Pacman — the package manager used
by the Arch distribution. It uses simple compressed files as a package
format, and maintains a text-based package database.


%package -n libalpm-devel
Summary: Development headers for libalpm
Requires: libalpm%{_isa} = %{version}-%{release}

%description -n libalpm-devel
This package contains the public headers necessary to use libalpm.


%package filesystem
Summary: Pacman filesystem layout
License: Public Domain
BuildArch: noarch

%description filesystem
This package provides some directories used by pacman and related
packages.


%prep
%setup -q -n %{name}-%{gitversion}

%build
./autogen.sh
%configure --enable-debug --enable-doxygen
make %{?_smp_mflags}

%install
%make_install
%find_lang pacman
%find_lang pacman-scripts
%find_lang libalpm
cat pacman-scripts.lang >> pacman.lang

# work around --disable-static not working
find %{buildroot} \( -name '*.a' -o -name '*.la' \) -print -delete
# work around some garbage files being installed
find %{buildroot} -name '*_BUILD_*' -print -delete

mkdir -p %{buildroot}%{_sysconfdir}/pacman.d
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pacman.d/

cat >>%{buildroot}%{_sysconfdir}/pacman.conf <<EOF
[core]
SigLevel = Required DatabaseOptional
Include = %{_sysconfdir}/pacman.d/mirrorlist
EOF


%post -n libalpm -p /sbin/ldconfig
%postun -n libalpm -p /sbin/ldconfig


%files -f pacman.lang
%{_bindir}/vercmp
%{_bindir}/testpkg
%{_bindir}/testdb
%{_bindir}/cleanupdelta
%{_bindir}/pacsort
%{_bindir}/pactree
%{_bindir}/pacman
%{_bindir}/makepkg
%{_bindir}/pacman-db-upgrade
%{_bindir}/pacman-key
%{_bindir}/pacman-optimize
%{_bindir}/pkgdelta
%{_bindir}/repo-add
%{_bindir}/makepkg-template
%{_bindir}/repo-elephant
%{_bindir}/repo-remove
%config(noreplace) %{_sysconfdir}/makepkg.conf
%config(noreplace) %{_sysconfdir}/pacman.conf
%config(noreplace) %{_sysconfdir}/pacman.d/mirrorlist
%dir %{_sharedstatedir}/pacman
%dir %{_localstatedir}/cache/pacman
%dir %{_localstatedir}/cache/pacman/pkg
%{_datadir}/pacman/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%doc COPYING NEWS

%files -n libalpm -f libalpm.lang
%{_libdir}/libalpm.so.%{libversion}
%{_libdir}/libalpm.so.%{libmajor}
%doc COPYING

%files -n libalpm-devel
%{_includedir}/alpm_list.h
%{_includedir}/alpm.h
%{_libdir}/pkgconfig/libalpm.pc
%{_libdir}/libalpm.so
%{_mandir}/man3/*
%doc COPYING HACKING

%files filesystem
%dir %{_sysconfdir}/pacman.d
%dir %{_datadir}/pacman


%changelog
* Thu Aug 22 2013 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.1.2-1.20130626git28cb22e
- Build from git snapshot.
- Include /etc/pacman.d/mirrorlist.
- Add pacman-filesystem package.
- Add missing build dependencies and fix other packaging issues.
- Package accepted (#998127).

* Fri Aug 16 2013 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 4.1.2-1
- Initial packaging.
